pub struct ProviderCapabilities {
pub namespace_tools: bool,
pub image_generation: bool,
pub web_search: bool,
}Expand description
Optional provider-backed features that Codex may expose at runtime.
These capabilities are a provider-owned upper bound. Callers can disable more functionality through normal config, but should not expose a feature that the active provider marks unsupported here.
Fields
namespace_tools: boolimage_generation: boolweb_search: boolTrait Implementations
Sourceimpl Clone for ProviderCapabilities
impl Clone for ProviderCapabilities
Sourcefn clone(&self) -> ProviderCapabilities
fn clone(&self) -> ProviderCapabilities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ProviderCapabilities
Sourceimpl Debug for ProviderCapabilities
impl Debug for ProviderCapabilities
Sourceimpl Default for ProviderCapabilities
impl Default for ProviderCapabilities
impl Eq for ProviderCapabilities
Sourceimpl PartialEq for ProviderCapabilities
impl PartialEq for ProviderCapabilities
impl StructuralPartialEq for ProviderCapabilities